@@ -109,6 +109,7 @@
 #include <parser_aux.h>
 #include <structure.h>
 #include <libtasn1.h>
+#include "c-ctype.h"
 
 static list_type *e_list = NULL;
 static FILE *file_asn1;			/* Pointer to file to parse */
@@ -145,7 +146,7 @@ static int _asn1_yylex(void);
 }
 #endif
 
-#line 149 "ASN1.c"
+#line 150 "ASN1.c"
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
@@ -289,13 +290,13 @@ extern int _asn1_yydebug;
 #if ! defined _ASN1_YYSTYPE && ! defined _ASN1_YYSTYPE_IS_DECLARED
 union _ASN1_YYSTYPE
 {
-#line 76 "ASN1.y"
+#line 77 "ASN1.y"
 
   unsigned int constant;
   char str[ASN1_MAX_NAME_SIZE+1];
   asn1_node node;
 
-#line 299 "ASN1.c"
+#line 300 "ASN1.c"
 
 };
 typedef union _ASN1_YYSTYPE _ASN1_YYSTYPE;
@@ -605,20 +606,20 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   150,   150,   163,   164,   167,   170,   171,   174,   175,
-     178,   179,   180,   183,   184,   187,   189,   194,   195,   199,
-     201,   206,   207,   211,   212,   213,   216,   218,   222,   223,
-     224,   227,   229,   230,   234,   235,   239,   240,   242,   243,
-     247,   250,   251,   254,   255,   259,   260,   263,   264,   267,
-     268,   271,   272,   275,   276,   279,   280,   283,   284,   287,
-     288,   291,   292,   295,   296,   299,   300,   303,   308,   309,
-     313,   314,   315,   320,   326,   329,   331,   333,   334,   335,
-     336,   337,   338,   339,   340,   341,   342,   343,   344,   345,
-     346,   347,   348,   349,   350,   351,   352,   353,   356,   357,
-     362,   363,   366,   369,   372,   373,   377,   379,   381,   385,
-     387,   389,   393,   397,   398,   403,   404,   405,   406,   407,
-     408,   409,   410,   413,   420,   423,   427,   432,   438,   439,
-     440,   443,   444,   448,   451,   453,   477,   478
+       0,   151,   151,   164,   165,   168,   171,   172,   175,   176,
+     179,   180,   181,   184,   185,   188,   190,   195,   196,   200,
+     202,   207,   208,   212,   213,   214,   217,   219,   223,   224,
+     225,   228,   230,   231,   235,   236,   240,   241,   243,   244,
+     248,   251,   252,   255,   256,   260,   261,   264,   265,   268,
+     269,   272,   273,   276,   277,   280,   281,   284,   285,   288,
+     289,   292,   293,   296,   297,   300,   301,   304,   309,   310,
+     314,   315,   316,   321,   327,   330,   332,   334,   335,   336,
+     337,   338,   339,   340,   341,   342,   343,   344,   345,   346,
+     347,   348,   349,   350,   351,   352,   353,   354,   357,   358,
+     363,   364,   367,   370,   373,   374,   378,   380,   382,   386,
+     388,   390,   394,   398,   399,   404,   405,   406,   407,   408,
+     409,   410,   411,   414,   421,   424,   428,   433,   439,   440,
+     441,   444,   445,   449,   452,   454,   478,   479
 };
 #endif
 
@@ -1574,7 +1575,7 @@ yyreduce:
   switch (yyn)
     {
   case 2:
-#line 153 "ASN1.y"
+#line 154 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_DEFINITIONS|(yyvsp[-5].constant));
                     _asn1_set_name((yyval.node),_asn1_get_name((yyvsp[-7].node)));
                     _asn1_set_name((yyvsp[-7].node),"");
@@ -1583,852 +1584,852 @@ yyreduce:
 
 		    p_tree=(yyval.node);
 		    }
-#line 1587 "ASN1.c"
+#line 1588 "ASN1.c"
     break;
 
   case 3:
-#line 163 "ASN1.y"
+#line 164 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1593 "ASN1.c"
+#line 1594 "ASN1.c"
     break;
 
   case 4:
-#line 164 "ASN1.y"
+#line 165 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1599 "ASN1.c"
+#line 1600 "ASN1.c"
     break;
 
   case 5:
-#line 167 "ASN1.y"
+#line 168 "ASN1.y"
     {SAFE_COPY((yyval.str),sizeof((yyval.str)),"-%s",(yyvsp[0].str));}
-#line 1605 "ASN1.c"
+#line 1606 "ASN1.c"
     break;
 
   case 6:
-#line 170 "ASN1.y"
+#line 171 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1611 "ASN1.c"
+#line 1612 "ASN1.c"
     break;
 
   case 7:
-#line 171 "ASN1.y"
+#line 172 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1617 "ASN1.c"
+#line 1618 "ASN1.c"
     break;
 
   case 8:
-#line 174 "ASN1.y"
+#line 175 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1623 "ASN1.c"
+#line 1624 "ASN1.c"
     break;
 
   case 9:
-#line 175 "ASN1.y"
+#line 176 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1629 "ASN1.c"
+#line 1630 "ASN1.c"
     break;
 
   case 10:
-#line 178 "ASN1.y"
+#line 179 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1635 "ASN1.c"
+#line 1636 "ASN1.c"
     break;
 
   case 11:
-#line 179 "ASN1.y"
+#line 180 "ASN1.y"
     {SAFE_COPY((yyval.str),sizeof((yyval.str)),"-%s",(yyvsp[0].str));}
-#line 1641 "ASN1.c"
+#line 1642 "ASN1.c"
     break;
 
   case 12:
-#line 180 "ASN1.y"
+#line 181 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1647 "ASN1.c"
+#line 1648 "ASN1.c"
     break;
 
   case 13:
-#line 183 "ASN1.y"
+#line 184 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1653 "ASN1.c"
+#line 1654 "ASN1.c"
     break;
 
   case 14:
-#line 184 "ASN1.y"
+#line 185 "ASN1.y"
     {snprintf((yyval.str),sizeof((yyval.str)),"%s",(yyvsp[0].str));}
-#line 1659 "ASN1.c"
+#line 1660 "ASN1.c"
     break;
 
   case 15:
-#line 187 "ASN1.y"
+#line 188 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_CONSTANT);
                                        _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 1666 "ASN1.c"
+#line 1667 "ASN1.c"
     break;
 
   case 16:
-#line 189 "ASN1.y"
+#line 190 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_CONSTANT);
 	                               _asn1_set_name((yyval.node),(yyvsp[-3].str));
                                        _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 1674 "ASN1.c"
+#line 1675 "ASN1.c"
     break;
 
   case 17:
-#line 194 "ASN1.y"
+#line 195 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 1680 "ASN1.c"
+#line 1681 "ASN1.c"
     break;
 
   case 18:
-#line 195 "ASN1.y"
+#line 196 "ASN1.y"
     {(yyval.node)=(yyvsp[-2].node);
                                             _asn1_set_right(_asn1_get_last_right((yyvsp[-2].node)),(yyvsp[0].node));}
-#line 1687 "ASN1.c"
+#line 1688 "ASN1.c"
     break;
 
   case 19:
-#line 199 "ASN1.y"
+#line 200 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_CONSTANT);
                                    _asn1_set_value((yyval.node),(yyvsp[0].str),strlen((yyvsp[0].str))+1);}
-#line 1694 "ASN1.c"
+#line 1695 "ASN1.c"
     break;
 
   case 20:
-#line 201 "ASN1.y"
+#line 202 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_CONSTANT);
 	                            _asn1_set_name((yyval.node),(yyvsp[-3].str));
                                     _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 1702 "ASN1.c"
+#line 1703 "ASN1.c"
     break;
 
   case 21:
-#line 206 "ASN1.y"
+#line 207 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 1708 "ASN1.c"
+#line 1709 "ASN1.c"
     break;
 
   case 22:
-#line 207 "ASN1.y"
+#line 208 "ASN1.y"
     {(yyval.node)=(yyvsp[-1].node);
                                                     _asn1_set_right(_asn1_get_last_right((yyvsp[-1].node)),(yyvsp[0].node));}
-#line 1715 "ASN1.c"
+#line 1716 "ASN1.c"
     break;
 
   case 23:
-#line 211 "ASN1.y"
+#line 212 "ASN1.y"
     {(yyval.constant)=CONST_UNIVERSAL;}
-#line 1721 "ASN1.c"
+#line 1722 "ASN1.c"
     break;
 
   case 24:
-#line 212 "ASN1.y"
+#line 213 "ASN1.y"
     {(yyval.constant)=CONST_PRIVATE;}
-#line 1727 "ASN1.c"
+#line 1728 "ASN1.c"
     break;
 
   case 25:
-#line 213 "ASN1.y"
+#line 214 "ASN1.y"
     {(yyval.constant)=CONST_APPLICATION;}
-#line 1733 "ASN1.c"
+#line 1734 "ASN1.c"
     break;
 
   case 26:
-#line 216 "ASN1.y"
+#line 217 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_TAG);
                             _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 1740 "ASN1.c"
+#line 1741 "ASN1.c"
     break;
 
   case 27:
-#line 218 "ASN1.y"
+#line 219 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_TAG | (yyvsp[-2].constant));
                                 _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 1747 "ASN1.c"
+#line 1748 "ASN1.c"
     break;
 
   case 28:
-#line 222 "ASN1.y"
+#line 223 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 1753 "ASN1.c"
+#line 1754 "ASN1.c"
     break;
 
   case 29:
-#line 223 "ASN1.y"
+#line 224 "ASN1.y"
     {(yyval.node)=_asn1_mod_type((yyvsp[-1].node),CONST_EXPLICIT);}
-#line 1759 "ASN1.c"
+#line 1760 "ASN1.c"
     break;
 
   case 30:
-#line 224 "ASN1.y"
+#line 225 "ASN1.y"
     {(yyval.node)=_asn1_mod_type((yyvsp[-1].node),CONST_IMPLICIT);}
-#line 1765 "ASN1.c"
+#line 1766 "ASN1.c"
     break;
 
   case 31:
-#line 227 "ASN1.y"
+#line 228 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_DEFAULT);
                                        _asn1_set_value((yyval.node),(yyvsp[0].str),strlen((yyvsp[0].str))+1);}
-#line 1772 "ASN1.c"
+#line 1773 "ASN1.c"
     break;
 
   case 32:
-#line 229 "ASN1.y"
+#line 230 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_DEFAULT|CONST_TRUE);}
-#line 1778 "ASN1.c"
+#line 1779 "ASN1.c"
     break;
 
   case 33:
-#line 230 "ASN1.y"
+#line 231 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_DEFAULT|CONST_FALSE);}
-#line 1784 "ASN1.c"
+#line 1785 "ASN1.c"
     break;
 
   case 36:
-#line 239 "ASN1.y"
+#line 240 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_INTEGER);}
-#line 1790 "ASN1.c"
+#line 1791 "ASN1.c"
     break;
 
   case 37:
-#line 240 "ASN1.y"
+#line 241 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_INTEGER|CONST_LIST);
 	                                 _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 1797 "ASN1.c"
+#line 1798 "ASN1.c"
     break;
 
   case 38:
-#line 242 "ASN1.y"
+#line 243 "ASN1.y"
     {(yyval.node)=(yyvsp[-3].node);}
-#line 1803 "ASN1.c"
+#line 1804 "ASN1.c"
     break;
 
   case 39:
-#line 244 "ASN1.y"
+#line 245 "ASN1.y"
     {(yyval.node)=(yyvsp[-6].node);}
-#line 1809 "ASN1.c"
+#line 1810 "ASN1.c"
     break;
 
   case 40:
-#line 247 "ASN1.y"
+#line 248 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_BOOLEAN);}
-#line 1815 "ASN1.c"
+#line 1816 "ASN1.c"
     break;
 
   case 41:
-#line 250 "ASN1.y"
+#line 251 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_UTC_TIME);}
-#line 1821 "ASN1.c"
+#line 1822 "ASN1.c"
     break;
 
   case 42:
-#line 251 "ASN1.y"
+#line 252 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_GENERALIZED_TIME);}
-#line 1827 "ASN1.c"
+#line 1828 "ASN1.c"
     break;
 
   case 43:
-#line 254 "ASN1.y"
+#line 255 "ASN1.y"
     { }
-#line 1833 "ASN1.c"
+#line 1834 "ASN1.c"
     break;
 
   case 44:
-#line 256 "ASN1.y"
+#line 257 "ASN1.y"
     { }
-#line 1839 "ASN1.c"
+#line 1840 "ASN1.c"
     break;
 
   case 45:
-#line 259 "ASN1.y"
+#line 260 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 1845 "ASN1.c"
+#line 1846 "ASN1.c"
     break;
 
   case 46:
-#line 260 "ASN1.y"
+#line 261 "ASN1.y"
     {(yyval.node)=(yyvsp[-1].node);}
-#line 1851 "ASN1.c"
+#line 1852 "ASN1.c"
     break;
 
   case 47:
-#line 263 "ASN1.y"
+#line 264 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_GENERALSTRING);}
-#line 1857 "ASN1.c"
+#line 1858 "ASN1.c"
     break;
 
   case 48:
-#line 264 "ASN1.y"
+#line 265 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_GENERALSTRING|CONST_SIZE);}
-#line 1863 "ASN1.c"
+#line 1864 "ASN1.c"
     break;
 
   case 49:
-#line 267 "ASN1.y"
+#line 268 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_NUMERIC_STRING|CONST_UNIVERSAL);}
-#line 1869 "ASN1.c"
+#line 1870 "ASN1.c"
     break;
 
   case 50:
-#line 268 "ASN1.y"
+#line 269 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_NUMERIC_STRING|CONST_SIZE);}
-#line 1875 "ASN1.c"
+#line 1876 "ASN1.c"
     break;
 
   case 51:
-#line 271 "ASN1.y"
+#line 272 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_IA5_STRING);}
-#line 1881 "ASN1.c"
+#line 1882 "ASN1.c"
     break;
 
   case 52:
-#line 272 "ASN1.y"
+#line 273 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_IA5_STRING|CONST_SIZE);}
-#line 1887 "ASN1.c"
+#line 1888 "ASN1.c"
     break;
 
   case 53:
-#line 275 "ASN1.y"
+#line 276 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_TELETEX_STRING);}
-#line 1893 "ASN1.c"
+#line 1894 "ASN1.c"
     break;
 
   case 54:
-#line 276 "ASN1.y"
+#line 277 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_TELETEX_STRING|CONST_SIZE);}
-#line 1899 "ASN1.c"
+#line 1900 "ASN1.c"
     break;
 
   case 55:
-#line 279 "ASN1.y"
+#line 280 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_PRINTABLE_STRING);}
-#line 1905 "ASN1.c"
+#line 1906 "ASN1.c"
     break;
 
   case 56:
-#line 280 "ASN1.y"
+#line 281 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_PRINTABLE_STRING|CONST_SIZE);}
-#line 1911 "ASN1.c"
+#line 1912 "ASN1.c"
     break;
 
   case 57:
-#line 283 "ASN1.y"
+#line 284 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_UNIVERSAL_STRING);}
-#line 1917 "ASN1.c"
+#line 1918 "ASN1.c"
     break;
 
   case 58:
-#line 284 "ASN1.y"
+#line 285 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_UNIVERSAL_STRING|CONST_SIZE);}
-#line 1923 "ASN1.c"
+#line 1924 "ASN1.c"
     break;
 
   case 59:
-#line 287 "ASN1.y"
+#line 288 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_BMP_STRING);}
-#line 1929 "ASN1.c"
+#line 1930 "ASN1.c"
     break;
 
   case 60:
-#line 288 "ASN1.y"
+#line 289 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_BMP_STRING|CONST_SIZE);}
-#line 1935 "ASN1.c"
+#line 1936 "ASN1.c"
     break;
 
   case 61:
-#line 291 "ASN1.y"
+#line 292 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_UTF8_STRING);}
-#line 1941 "ASN1.c"
+#line 1942 "ASN1.c"
     break;
 
   case 62:
-#line 292 "ASN1.y"
+#line 293 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_UTF8_STRING|CONST_SIZE);}
-#line 1947 "ASN1.c"
+#line 1948 "ASN1.c"
     break;
 
   case 63:
-#line 295 "ASN1.y"
+#line 296 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_VISIBLE_STRING);}
-#line 1953 "ASN1.c"
+#line 1954 "ASN1.c"
     break;
 
   case 64:
-#line 296 "ASN1.y"
+#line 297 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_VISIBLE_STRING|CONST_SIZE);}
-#line 1959 "ASN1.c"
+#line 1960 "ASN1.c"
     break;
 
   case 65:
-#line 299 "ASN1.y"
+#line 300 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OCTET_STRING);}
-#line 1965 "ASN1.c"
+#line 1966 "ASN1.c"
     break;
 
   case 66:
-#line 300 "ASN1.y"
+#line 301 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OCTET_STRING|CONST_SIZE);}
-#line 1971 "ASN1.c"
+#line 1972 "ASN1.c"
     break;
 
   case 67:
-#line 303 "ASN1.y"
+#line 304 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_CONSTANT);
 	                           _asn1_set_name((yyval.node),(yyvsp[-3].str));
                                     _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 1979 "ASN1.c"
+#line 1980 "ASN1.c"
     break;
 
   case 68:
-#line 308 "ASN1.y"
+#line 309 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 1985 "ASN1.c"
+#line 1986 "ASN1.c"
     break;
 
   case 69:
-#line 309 "ASN1.y"
+#line 310 "ASN1.y"
     {(yyval.node)=(yyvsp[-2].node);
                                                        _asn1_set_right(_asn1_get_last_right((yyvsp[-2].node)),(yyvsp[0].node));}
-#line 1992 "ASN1.c"
+#line 1993 "ASN1.c"
     break;
 
   case 70:
-#line 313 "ASN1.y"
+#line 314 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_BIT_STRING);}
-#line 1998 "ASN1.c"
+#line 1999 "ASN1.c"
     break;
 
   case 71:
-#line 314 "ASN1.y"
+#line 315 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_BIT_STRING|CONST_SIZE);}
-#line 2004 "ASN1.c"
+#line 2005 "ASN1.c"
     break;
 
   case 72:
-#line 316 "ASN1.y"
+#line 317 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_BIT_STRING|CONST_LIST);
                                 _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2011 "ASN1.c"
+#line 2012 "ASN1.c"
     break;
 
   case 73:
-#line 321 "ASN1.y"
+#line 322 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_ENUMERATED|CONST_LIST);
                                 _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2018 "ASN1.c"
+#line 2019 "ASN1.c"
     break;
 
   case 74:
-#line 326 "ASN1.y"
+#line 327 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OBJECT_ID);}
-#line 2024 "ASN1.c"
+#line 2025 "ASN1.c"
     break;
 
   case 75:
-#line 329 "ASN1.y"
+#line 330 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_IDENTIFIER);
                                        _asn1_set_value((yyval.node),(yyvsp[0].str),strlen((yyvsp[0].str))+1);}
-#line 2031 "ASN1.c"
+#line 2032 "ASN1.c"
     break;
 
   case 76:
-#line 331 "ASN1.y"
+#line 332 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_IDENTIFIER|CONST_SIZE);
                                        _asn1_set_value((yyval.node),(yyvsp[-1].str),strlen((yyvsp[-1].str))+1);}
-#line 2038 "ASN1.c"
+#line 2039 "ASN1.c"
     break;
 
   case 77:
-#line 333 "ASN1.y"
+#line 334 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2044 "ASN1.c"
+#line 2045 "ASN1.c"
     break;
 
   case 78:
-#line 334 "ASN1.y"
+#line 335 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2050 "ASN1.c"
+#line 2051 "ASN1.c"
     break;
 
   case 79:
-#line 335 "ASN1.y"
+#line 336 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2056 "ASN1.c"
+#line 2057 "ASN1.c"
     break;
 
   case 81:
-#line 337 "ASN1.y"
+#line 338 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2062 "ASN1.c"
+#line 2063 "ASN1.c"
     break;
 
   case 82:
-#line 338 "ASN1.y"
+#line 339 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2068 "ASN1.c"
+#line 2069 "ASN1.c"
     break;
 
   case 83:
-#line 339 "ASN1.y"
+#line 340 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2074 "ASN1.c"
+#line 2075 "ASN1.c"
     break;
 
   case 84:
-#line 340 "ASN1.y"
+#line 341 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2080 "ASN1.c"
+#line 2081 "ASN1.c"
     break;
 
   case 85:
-#line 341 "ASN1.y"
+#line 342 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2086 "ASN1.c"
+#line 2087 "ASN1.c"
     break;
 
   case 86:
-#line 342 "ASN1.y"
+#line 343 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2092 "ASN1.c"
+#line 2093 "ASN1.c"
     break;
 
   case 87:
-#line 343 "ASN1.y"
+#line 344 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2098 "ASN1.c"
+#line 2099 "ASN1.c"
     break;
 
   case 88:
-#line 344 "ASN1.y"
+#line 345 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2104 "ASN1.c"
+#line 2105 "ASN1.c"
     break;
 
   case 89:
-#line 345 "ASN1.y"
+#line 346 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2110 "ASN1.c"
+#line 2111 "ASN1.c"
     break;
 
   case 90:
-#line 346 "ASN1.y"
+#line 347 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2116 "ASN1.c"
+#line 2117 "ASN1.c"
     break;
 
   case 91:
-#line 347 "ASN1.y"
+#line 348 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2122 "ASN1.c"
+#line 2123 "ASN1.c"
     break;
 
   case 92:
-#line 348 "ASN1.y"
+#line 349 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2128 "ASN1.c"
+#line 2129 "ASN1.c"
     break;
 
   case 93:
-#line 349 "ASN1.y"
+#line 350 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2134 "ASN1.c"
+#line 2135 "ASN1.c"
     break;
 
   case 94:
-#line 350 "ASN1.y"
+#line 351 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2140 "ASN1.c"
+#line 2141 "ASN1.c"
     break;
 
   case 95:
-#line 351 "ASN1.y"
+#line 352 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2146 "ASN1.c"
+#line 2147 "ASN1.c"
     break;
 
   case 96:
-#line 352 "ASN1.y"
+#line 353 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2152 "ASN1.c"
+#line 2153 "ASN1.c"
     break;
 
   case 97:
-#line 353 "ASN1.y"
+#line 354 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_NULL);}
-#line 2158 "ASN1.c"
+#line 2159 "ASN1.c"
     break;
 
   case 98:
-#line 356 "ASN1.y"
+#line 357 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2164 "ASN1.c"
+#line 2165 "ASN1.c"
     break;
 
   case 99:
-#line 357 "ASN1.y"
+#line 358 "ASN1.y"
     {(yyval.node)=_asn1_mod_type((yyvsp[0].node),CONST_TAG);
                                                _asn1_set_right((yyvsp[-1].node),_asn1_get_down((yyval.node)));
                                                _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2172 "ASN1.c"
+#line 2173 "ASN1.c"
     break;
 
   case 100:
-#line 362 "ASN1.y"
+#line 363 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2178 "ASN1.c"
+#line 2179 "ASN1.c"
     break;
 
   case 101:
-#line 363 "ASN1.y"
+#line 364 "ASN1.y"
     {(yyval.node)=_asn1_mod_type((yyvsp[-1].node),CONST_DEFAULT);
                                                        _asn1_set_right((yyvsp[0].node),_asn1_get_down((yyval.node)));
 						       _asn1_set_down((yyval.node),(yyvsp[0].node));}
-#line 2186 "ASN1.c"
+#line 2187 "ASN1.c"
     break;
 
   case 102:
-#line 366 "ASN1.y"
+#line 367 "ASN1.y"
     {(yyval.node)=_asn1_mod_type((yyvsp[-1].node),CONST_OPTION);}
-#line 2192 "ASN1.c"
+#line 2193 "ASN1.c"
     break;
 
   case 103:
-#line 369 "ASN1.y"
+#line 370 "ASN1.y"
     {(yyval.node)=_asn1_set_name((yyvsp[0].node),(yyvsp[-1].str));}
-#line 2198 "ASN1.c"
+#line 2199 "ASN1.c"
     break;
 
   case 104:
-#line 372 "ASN1.y"
+#line 373 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2204 "ASN1.c"
+#line 2205 "ASN1.c"
     break;
 
   case 105:
-#line 373 "ASN1.y"
+#line 374 "ASN1.y"
     {(yyval.node)=(yyvsp[-2].node);
                                                 _asn1_set_right(_asn1_get_last_right((yyvsp[-2].node)),(yyvsp[0].node));}
-#line 2211 "ASN1.c"
+#line 2212 "ASN1.c"
     break;
 
   case 106:
-#line 377 "ASN1.y"
+#line 378 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_SEQUENCE);
                                               _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2218 "ASN1.c"
+#line 2219 "ASN1.c"
     break;
 
   case 107:
-#line 379 "ASN1.y"
+#line 380 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_SEQUENCE_OF);
                                               _asn1_set_down((yyval.node),(yyvsp[0].node));}
-#line 2225 "ASN1.c"
+#line 2226 "ASN1.c"
     break;
 
   case 108:
-#line 381 "ASN1.y"
+#line 382 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_SEQUENCE_OF|CONST_SIZE);
                                             _asn1_set_down((yyval.node),(yyvsp[0].node));}
-#line 2232 "ASN1.c"
+#line 2233 "ASN1.c"
     break;
 
   case 109:
-#line 385 "ASN1.y"
+#line 386 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_SET);
                                      _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2239 "ASN1.c"
+#line 2240 "ASN1.c"
     break;
 
   case 110:
-#line 387 "ASN1.y"
+#line 388 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_SET_OF);
                                      _asn1_set_down((yyval.node),(yyvsp[0].node));}
-#line 2246 "ASN1.c"
+#line 2247 "ASN1.c"
     break;
 
   case 111:
-#line 389 "ASN1.y"
+#line 390 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_SET_OF|CONST_SIZE);
                                        _asn1_set_down((yyval.node),(yyvsp[0].node));}
-#line 2253 "ASN1.c"
+#line 2254 "ASN1.c"
     break;
 
   case 112:
-#line 393 "ASN1.y"
+#line 394 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_CHOICE);
                                              _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2260 "ASN1.c"
+#line 2261 "ASN1.c"
     break;
 
   case 113:
-#line 397 "ASN1.y"
+#line 398 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_ANY);}
-#line 2266 "ASN1.c"
+#line 2267 "ASN1.c"
     break;
 
   case 114:
-#line 398 "ASN1.y"
+#line 399 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_ANY|CONST_DEFINED_BY);
                                         _asn1_set_down((yyval.node),_asn1_add_static_node(&e_list, ASN1_ETYPE_CONSTANT));
 	                                _asn1_set_name(_asn1_get_down((yyval.node)),(yyvsp[0].str));}
-#line 2274 "ASN1.c"
+#line 2275 "ASN1.c"
     break;
 
   case 115:
-#line 403 "ASN1.y"
+#line 404 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2280 "ASN1.c"
+#line 2281 "ASN1.c"
     break;
 
   case 116:
-#line 404 "ASN1.y"
+#line 405 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2286 "ASN1.c"
+#line 2287 "ASN1.c"
     break;
 
   case 117:
-#line 405 "ASN1.y"
+#line 406 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2292 "ASN1.c"
+#line 2293 "ASN1.c"
     break;
 
   case 118:
-#line 406 "ASN1.y"
+#line 407 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2298 "ASN1.c"
+#line 2299 "ASN1.c"
     break;
 
   case 119:
-#line 407 "ASN1.y"
+#line 408 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2304 "ASN1.c"
+#line 2305 "ASN1.c"
     break;
 
   case 120:
-#line 408 "ASN1.y"
+#line 409 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2310 "ASN1.c"
+#line 2311 "ASN1.c"
     break;
 
   case 121:
-#line 409 "ASN1.y"
+#line 410 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2316 "ASN1.c"
+#line 2317 "ASN1.c"
     break;
 
   case 122:
-#line 410 "ASN1.y"
+#line 411 "ASN1.y"
     { SAFE_COPY((yyval.str),sizeof((yyval.str)),"%s",last_token); }
-#line 2322 "ASN1.c"
+#line 2323 "ASN1.c"
     break;
 
   case 123:
-#line 413 "ASN1.y"
+#line 414 "ASN1.y"
     {
 #ifndef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
 	fprintf(stderr, "%s:%u: Warning: %s is a built-in ASN.1 type.\n", file_name, line_number, (yyvsp[-8].str));
 #endif
 }
-#line 2332 "ASN1.c"
+#line 2333 "ASN1.c"
     break;
 
   case 124:
-#line 420 "ASN1.y"
+#line 421 "ASN1.y"
     { (yyval.node)=_asn1_set_name((yyvsp[0].node),(yyvsp[-2].str));}
-#line 2338 "ASN1.c"
+#line 2339 "ASN1.c"
     break;
 
   case 125:
-#line 424 "ASN1.y"
+#line 425 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OBJECT_ID|CONST_ASSIGN);
                          _asn1_set_name((yyval.node),(yyvsp[-6].str));
                          _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2346 "ASN1.c"
+#line 2347 "ASN1.c"
     break;
 
   case 126:
-#line 428 "ASN1.y"
+#line 429 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OBJECT_ID|CONST_ASSIGN|CONST_1_PARAM);
                          _asn1_set_name((yyval.node),(yyvsp[-5].str));
                          _asn1_set_value((yyval.node),(yyvsp[-4].str),strlen((yyvsp[-4].str))+1);
                          _asn1_set_down((yyval.node),(yyvsp[-1].node));}
-#line 2355 "ASN1.c"
+#line 2356 "ASN1.c"
     break;
 
   case 127:
-#line 433 "ASN1.y"
+#line 434 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_INTEGER|CONST_ASSIGN);
                          _asn1_set_name((yyval.node),(yyvsp[-3].str));
                          _asn1_set_value((yyval.node),(yyvsp[0].str),strlen((yyvsp[0].str))+1);}
-#line 2363 "ASN1.c"
+#line 2364 "ASN1.c"
     break;
 
   case 128:
-#line 438 "ASN1.y"
+#line 439 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2369 "ASN1.c"
+#line 2370 "ASN1.c"
     break;
 
   case 129:
-#line 439 "ASN1.y"
+#line 440 "ASN1.y"
     {(yyval.node)=NULL;}
-#line 2375 "ASN1.c"
+#line 2376 "ASN1.c"
     break;
 
   case 130:
-#line 440 "ASN1.y"
+#line 441 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2381 "ASN1.c"
+#line 2382 "ASN1.c"
     break;
 
   case 131:
-#line 443 "ASN1.y"
+#line 444 "ASN1.y"
     {(yyval.node)=(yyvsp[0].node);}
-#line 2387 "ASN1.c"
+#line 2388 "ASN1.c"
     break;
 
   case 132:
-#line 444 "ASN1.y"
+#line 445 "ASN1.y"
     {(yyval.node)=(yyvsp[-1].node);
                                                           if ((yyvsp[-1].node) && (yyvsp[0].node)) _asn1_set_right(_asn1_get_last_right((yyvsp[-1].node)),(yyvsp[0].node));}
-#line 2394 "ASN1.c"
+#line 2395 "ASN1.c"
     break;
 
   case 133:
-#line 448 "ASN1.y"
+#line 449 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OBJECT_ID);
                                                           _asn1_set_down((yyval.node),(yyvsp[-1].node));
                                                           _asn1_set_name((yyval.node),(yyvsp[-3].str));}
-#line 2402 "ASN1.c"
+#line 2403 "ASN1.c"
     break;
 
   case 134:
-#line 451 "ASN1.y"
+#line 452 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OBJECT_ID);
                                                           _asn1_set_name((yyval.node),(yyvsp[-2].str));}
-#line 2409 "ASN1.c"
+#line 2410 "ASN1.c"
     break;
 
   case 135:
-#line 453 "ASN1.y"
+#line 454 "ASN1.y"
     {(yyval.node)=_asn1_add_static_node(&e_list, ASN1_ETYPE_OBJECT_ID);
                                                           _asn1_set_name((yyval.node),(yyvsp[0].str));}
-#line 2416 "ASN1.c"
+#line 2417 "ASN1.c"
     break;
 
   case 136:
-#line 477 "ASN1.y"
+#line 478 "ASN1.y"
     {(yyval.constant)=CONST_EXPLICIT;}
-#line 2422 "ASN1.c"
+#line 2423 "ASN1.c"
     break;
 
   case 137:
-#line 478 "ASN1.y"
+#line 479 "ASN1.y"
     {(yyval.constant)=CONST_IMPLICIT;}
-#line 2428 "ASN1.c"
+#line 2429 "ASN1.c"
     break;
 
 
-#line 2432 "ASN1.c"
+#line 2433 "ASN1.c"
 
       default: break;
     }
@@ -2660,7 +2661,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 482 "ASN1.y"
+#line 483 "ASN1.y"
 
 
 
@@ -2769,7 +2770,7 @@ _asn1_yylex (void)
 
       /* Is STRING a number? */
       for (k = 0; k < counter; k++)
-        if (!isdigit ((int)string[k]))
+        if (!c_isdigit ((int)string[k]))
           break;
       if (k >= counter)
         {
